pub fn annotate_benchmark_profile(
record: &mut BenchmarkRecord,
profile: &BenchmarkProfile,
)Expand description
Adds the selected profile metadata to one benchmark record.
pub fn annotate_benchmark_profile(
record: &mut BenchmarkRecord,
profile: &BenchmarkProfile,
)Adds the selected profile metadata to one benchmark record.